==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/awt/EnhancedMouseEvent.hpp <==
#ifndef _COM_SUN_STAR_AWT_ENHANCEDMOUSEEVENT_HPP_
#define _COM_SUN_STAR_AWT_ENHANCEDMOUSEEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_AWT_ENHANCEDMOUSEEVENT_HDL_
#include "com/sun/star/awt/EnhancedMouseEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_AWT_MOUSEEVENT_HPP_
#include "com/sun/star/awt/MouseEvent.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace awt {

inline EnhancedMouseEvent::EnhancedMouseEvent() SAL_THROW( () )
    : ::com::sun::star::awt::MouseEvent()
    , Target()
{
}

inline EnhancedMouseEvent::EnhancedMouseEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::sal_Int16& Modifiers_, const ::sal_Int16& Buttons_, const ::sal_Int32& X_, const ::sal_Int32& Y_, const ::sal_Int32& ClickCount_, const ::sal_Bool& PopupTrigger_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Target_) SAL_THROW( () )
    : ::com::sun::star::awt::MouseEvent(Source_, Modifiers_, Buttons_, X_, Y_, ClickCount_, PopupTrigger_)
    , Target(Target_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::awt::EnhancedMouseEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.awt.EnhancedMouseEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_AWT_ENHANCEDMOUSEEVENT_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/awt/EnhancedMouseEvent.hpp <==
#ifndef _COM_SUN_STAR_AWT_ENHANCEDMOUSEEVENT_HPP_
#define _COM_SUN_STAR_AWT_ENHANCEDMOUSEEVENT_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_AWT_ENHANCEDMOUSEEVENT_HDL_
#include "com/sun/star/awt/EnhancedMouseEvent.hdl"
#endif

#ifndef _COM_SUN_STAR_AWT_MOUSEEVENT_HPP_
#include "com/sun/star/awt/MouseEvent.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_XINTERFACE_HPP_
#include "com/sun/star/uno/XInterface.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace awt {

inline EnhancedMouseEvent::EnhancedMouseEvent() SAL_THROW( () )
    : ::com::sun::star::awt::MouseEvent()
    , Target()
{
}

inline EnhancedMouseEvent::EnhancedMouseEvent(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Source_, const ::sal_Int16& Modifiers_, const ::sal_Int16& Buttons_, const ::sal_Int32& X_, const ::sal_Int32& Y_, const ::sal_Int32& ClickCount_, const ::sal_Bool& PopupTrigger_, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Target_) SAL_THROW( () )
    : ::com::sun::star::awt::MouseEvent(Source_, Modifiers_, Buttons_, X_, Y_, ClickCount_, PopupTrigger_)
    , Target(Target_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace awt {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::awt::EnhancedMouseEvent const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.awt.EnhancedMouseEvent");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::awt::EnhancedMouseEvent const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::awt::EnhancedMouseEvent >::get();
}

#endif // _COM_SUN_STAR_AWT_ENHANCEDMOUSEEVENT_HPP_
